@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-__version__ = "0.5.1"
+__version__ = "0.6.1"
 
 import datetime
 import os
@@ -165,7 +165,9 @@ def audit_(
 
     if len(config.sources) == 0:
         raise click.ClickException(
-            "Please specify or configure at least one advisory source."
+            click.style(
+                "Please specify or configure at least one advisory source!", fg="red"
+            )
         )
 
     packages = list(extract_dependencies_from_files(config, files, file_format))
