@@ -7,6 +7,7 @@ from typing import Any, Callable, Dict, List, Tuple, Union
 
 from packaging import specifiers
 from packaging.utils import NormalizedName, canonicalize_name
+from packaging.version import Version
 
 from skjold.core import Dependency, SecurityAdvisory, SecurityAdvisorySource
 from skjold.tasks import register_source
@@ -24,7 +25,7 @@ class PyUpSecurityAdvisory(SecurityAdvisory):
 
     @property
     def identifier(self) -> str:
-        return self._json["id"]
+        return self._json["cve"]
 
     @property
     def source(self) -> str:
@@ -68,7 +69,7 @@ class PyUpSecurityAdvisory(SecurityAdvisory):
         return ",".join([str(x) for x in self.vulnerable_version_range])
 
     def is_affected(self, version: str) -> bool:
-        version_ = specifiers.parse(version)
+        version_ = Version(version)
         allows_: Callable[[specifiers.SpecifierSet], bool] = (
             lambda x: True if version_ in x else False
         )
